Welcome to the documentation of Trade Dangerous
===============================================
![alt text][logo]

----------

Copyright (C) Oliver "kfsone" Smith, July 2014

Copyright (C) Bernd 'Gazelle' Gollesch 2016, 2017

Copyright (C) Jonathan 'eyeonus' Jones 2018, 2019

_REQUIRES PYTHON 3.4.2 OR HIGHER._

----------

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   about
   installation
   develop
   source/modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


[logo]: https://raw.githubusercontent.com/wiki/eyeonus/Trade-Dangerous/TradeDangerousCrest.png "Elite Dangerous Crest"
